# Potentials

::: sbi.inference.potentials.posterior_based_potential.posterior_estimator_based_potential
    selection:
      filters: [ "!^_", "^__", "!^__class__" ]
      inherited_members: true

::: sbi.inference.potentials.likelihood_based_potential.likelihood_estimator_based_potential
    selection:
      filters: [ "!^_", "^__", "!^__class__" ]
      inherited_members: true

::: sbi.inference.potentials.ratio_based_potential.ratio_estimator_based_potential
    selection:
      filters: [ "!^_", "^__", "!^__class__" ]
      inherited_members: true

::: sbi.inference.potentials.score_based_potential.score_estimator_based_potential
    selection:
      filters: [ "!^_", "^__", "!^__class__" ]
      inherited_members: true
